The promise of the bell : Christmas in Philadelphia by Agnes Repplier | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# The promise of the bell : Christmas in Philadelphia by Agnes Repplier

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/75219.html.images | 46 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/75219.epub3.images | 745 kB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/75219.epub.images | 744 kB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/75219.epub.noimages | 235 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/75219.kf8.images | 1.4 MB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/75219.kindle.images | 1.4 MB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/75219.txt.utf-8 | 36 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/75219/pg75219-h.zip | 1.1 MB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…

## About this eBook

Author | Repplier, Agnes, 1855-1950
Illustrator | Adams, John Wolcott, 1874-1925
Title | The promise of the bell : Christmas in Philadelphia
Original Publication | United States: Houghton Mifflin Company, 1924.
Credits | Bob Taylor and The Online Distributed Proofreading Team at https://www.pgdp.net (This book was produced from images made available by the HathiTrust Digital Library.)
Language | English
Category | Text
EBook-No. | 75219
Release Date | Jan 26, 2025
Copyright Status | Public domain in the USA.
Downloads | 159 downloads in the last 30 days.
Project Gutenberg eBooks are always free!